﻿// This file contains just some helpful functions. Nothing major.

using System;
using System.Windows.Forms;
using System.Text.RegularExpressions;

namespace Editor {
    public partial class EditorForm : Form {

        private bool PromptDYWTS() { // prompt the user if they want to save
            if (Saved)
                return false;

            switch (MessageBox.Show(this, "Do you want to save your current file?", "Editor", MessageBoxButtons.YesNoCancel, MessageBoxIcon.Warning)) {
                case DialogResult.Yes:
                    SaveFile();
                    return false;
                case DialogResult.Cancel:
                    return true;
                default:
                    return false;
            }
        }

        private void SrchNotFound() {
            ScrollToTop();
            Status = "Search string not found";
            MessageBox.Show(this, "The search string was not found.", "Search", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }

        private void ScrollToTop() {
            textBox.Select(0, 0);
            textBox.ScrollToCaret();
        }

        // replaces unicode escape sequences (\uHHHH) with the unicode char in question
        private static string ParseUnicode(string text) {
            MatchCollection matches = Regex.Matches(text, @"\\u[0-9A-Fa-f]{4}");
            string result = text;

            foreach (Match m in matches)
                result = result.Replace(m.Value,
                    ((char)uint.Parse(m.Value.Substring(2), System.Globalization.NumberStyles.HexNumber)).ToString());

            return result;
        }

        // replace escape sequences with the actual character
        private static string ParseEscape(string str) {

            string ret = str;

            ret = ret.Replace("\\t", "\t");
            ret = ret.Replace("\\n", "\r\n");
            ret = ret.Replace("\\r", "");
            ret = ret.Replace("\\0", "\0");
            ret = ret.Replace("\\b", "\b");

            return ParseUnicode(ret);
        }

        private static string FixNewlines(string str) {
            return str.Replace("\r\n", "\n").Replace("\n", "\r\n");
        }

        // count the occurances of a str within another str
        private static int CountOccurances(string target, string str) {
            int c = 0;
            int i = 0;

            do {
                i = target.IndexOf(str, i);

                if (i == -1)
                    break;

                i += str.Length;
                c++;
            } while (true);

            return c;
        }

        private static int CountOccurances(string target, char chr) {
            return CountOccurances(target, chr.ToString());
        }
    }
}